@@ -5,9 +5,9 @@
 from .core import *
 
 # Event Class
-class event: 
+class event:
     # Constructor ###############################################################
-    def __init__(self,timestamp,latitude:float,longitude:float,detector_id:str,event_id:str='',mission:str='',time_format:str='mjd',event_type:str='TGF'):
+    def __init__(self,timestamp,latitude:float,longitude:float,detector_id:str,event_id:str='',mission:str='',time_format:str='mjd',event_type:str='TGF', property:float=0):
         """Event: A point with longitude and latitude over the earth with a timestamp
 
         Args:
@@ -28,6 +28,7 @@ class event:
         self.event_id       = event_id
         self.mission        = mission
         self.event_type     = event_type
+        self.property       = property
 
     
     # SOME FUNCTIONS FOR THE TGF CLASS ##########################################
@@ -38,7 +39,8 @@ class event:
         Timestamp (ISO): %s
         Lat: %9.4f \t Long: %9.4f
         Detector_id: %s
-        '''%(self.event_type,self.event_id,self.mission,self.get_iso(),self.latitude,self.longitude,self.detector_id)
+        Property: %f
+        '''%(self.event_type,self.event_id,self.mission,self.get_iso(),self.latitude,self.longitude,self.detector_id,self.property)
 
         return str
 
